## ----options, include=FALSE---------------------------------------------------
library(knitr)
opts_chunk$set(
    echo = TRUE,
    eval = TRUE,
    message = FALSE,
    warning = FALSE,
    collapse = FALSE,
    comment = NA,
    prompt = FALSE,
    tidy = FALSE,
    dev = "png",
    out.width = "100%"
)

## check the output type
out_type <- opts_knit$get("rmarkdown.pandoc.to")
if (is.null(out_type)) {
    out_type <- "html"
}

## add styling
if (out_type == "html") {
    BiocStyle::markdown()
} else if (out_type == "latex") {
    BiocStyle::latex()
}

## ----load-package-------------------------------------------------------------
library(Rega)

## ----env-credentials----------------------------------------------------------
Sys.setenv("REGA_EGA_USERNAME" = "<your-ega-username>")
Sys.setenv("REGA_EGA_PASSWORD" = "<your-ega-password>")

## ----parse-metadata-----------------------------------------------------------
metadata_file <- system.file(
    "extdata/submission_example.xlsx",
    package = "Rega"
)

parsed_metadata <- default_parser(metadata_file)
parsed_metadata

## ----validate-metadata--------------------------------------------------------
validation_summary <- default_validator(parsed_metadata)
validation_summary

## ----extract-api--------------------------------------------------------------
api <- extract_api()

## ----client-with-oauth--------------------------------------------------------
ega <- create_client(api, verbosity = 0)

## ----run-workflow, eval=FALSE-------------------------------------------------
# responses <- new_submission(parsed_metadata, ega, "log.yaml")

## ----get-submission-contents, eval=FALSE--------------------------------------
# resp <- get_submission(00001, ega, logfile = "log.yaml")
# resp <- get_submission(00001, ega)

## ----delete-submission-contents, eval=FALSE-----------------------------------
# resp <- delete_submission_contents(00001, ega)
# resp <- delete_submission(00001, ega)

## ----client-with-token, eval=FALSE--------------------------------------------
# bt <- ega_token()
# ega <- create_client(api, bt$access_token)
# 
# ega$get__enums()

## ----session-info-------------------------------------------------------------
sessionInfo()

