% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/apiclient.R
\name{parse_ega_body}
\alias{parse_ega_body}
\title{Parse The Information From EGA httr2 Response Object.}
\usage{
parse_ega_body(resp)
}
\arguments{
\item{resp}{An HTTP response object from the EGA API.}
}
\value{
A tibble containing the parsed and formatted response data. If the
response is plain text without a JSON-like structure, a one-column tibble
is returned with the raw content.
}
\description{
Parses the body of a body of \code{httr2} response object from the EGA API,
handling JSON and plain text content, and formats it into a tibble for
further processing.
}
\examples{
# Example with JSON response
json_resp <- httr2::response(
    method = "GET",
    url = "https://www.example.com/api/files",
    status = 200,
    headers = list("content-type" = "application/json"),
    body = charToRaw('[{"id": 1, "name": "test"}]')
)
parse_ega_body(json_resp)

# Example with plain text response
text_resp <- httr2::response(
    method = "POST",
    url = "https://www.example.com/api/submissions",
    status = 200,
    headers = list("content-type" = "text/plain"),
    body = charToRaw("Sample response text")
)
parse_ega_body(text_resp)

}
